@@ -178,7 +178,7 @@ void KCalculator::setupMainActions() {
 	KStandardAction::redo(calc_display, SLOT(slotHistoryForward()), actionCollection());
 	KStandardAction::cut(calc_display, SLOT(slotCut()), actionCollection());
 	KStandardAction::copy(calc_display, SLOT(slotCopy()), actionCollection());
-	KStandardAction::paste(calc_display, SLOT(slotPaste()), actionCollection());
+	KStandardAction::paste(this, SLOT(slotPaste()), actionCollection());
 
 	// mode menu
 	QActionGroup *modeGroup = new QActionGroup(this);
@@ -723,6 +723,7 @@ void KCalculator::slotConstantToDisplay(const science_constant &const_chosen) {
 	val.replace(QLatin1Char('.'), KNumber::decimalSeparator());
 	calc_display->setAmount(KNumber(val));
     updateDisplay({});
+    core.setOnlyUpdateOperation(false);
 }
 
 //------------------------------------------------------------------------------
@@ -760,12 +761,12 @@ void KCalculator::slotBaseSelected(QAbstractButton *button) {
 
 	// Enable the buttons available in this base
 	for (int i = 0; i < current_base; ++i) {
-		(num_button_group_->buttons()[i])->setEnabled(true);
+                (num_button_group_->buttons().at(i))->setEnabled(true);
 	}
 
 	// Disable the buttons not available in this base
 	for (int i = current_base; i < 16; ++i) {
-		(num_button_group_->buttons()[i])->setEnabled(false);
+                (num_button_group_->buttons().at(i))->setEnabled(false);
 	}
 
 	// Only enable the decimal point in decimal
@@ -936,6 +937,7 @@ void KCalculator::slotMemRecallclicked() {
 
 	calc_display->setAmount(memory_num_);
     updateDisplay({});
+    core.setOnlyUpdateOperation(false);
 }
 
 //------------------------------------------------------------------------------
@@ -1485,6 +1487,7 @@ void KCalculator::slotStatNumclicked() {
 	}
 
 	updateDisplay(UPDATE_FROM_CORE);
+    core.setOnlyUpdateOperation(false);
 }
 
 //------------------------------------------------------------------------------
@@ -1501,6 +1504,7 @@ void KCalculator::slotStatMeanclicked() {
 	}
 
 	updateDisplay(UPDATE_FROM_CORE);
+    core.setOnlyUpdateOperation(false);
 }
 
 //------------------------------------------------------------------------------
@@ -1519,6 +1523,7 @@ void KCalculator::slotStatStdDevclicked() {
 	}
 
 	updateDisplay(UPDATE_FROM_CORE);
+    core.setOnlyUpdateOperation(false);
 }
 
 //------------------------------------------------------------------------------
@@ -1538,6 +1543,7 @@ void KCalculator::slotStatMedianclicked() {
 
 	// TODO: it seems two different modes should be implemented, but...?
 	updateDisplay(UPDATE_FROM_CORE);
+    core.setOnlyUpdateOperation(false);
 }
 
 //------------------------------------------------------------------------------
@@ -1555,6 +1561,7 @@ void KCalculator::slotStatDataInputclicked() {
 	}
 
 	updateDisplay(UPDATE_FROM_CORE);
+    core.setOnlyUpdateOperation(false);
 }
 
 //------------------------------------------------------------------------------
@@ -1603,6 +1610,7 @@ void KCalculator::slotConstclicked(int button) {
 		}
 
         updateDisplay({});
+        core.setOnlyUpdateOperation(false);
 	}
 }
 
@@ -1883,7 +1891,7 @@ void KCalculator::slotSetNumeralMode() {
 // Name: slotBaseModeAmountChanged
 // Desc: updates numerical base conversions
 //------------------------------------------------------------------------------
-void KCalculator::slotBaseModeAmountChanged(KNumber number) {
+void KCalculator::slotBaseModeAmountChanged(const KNumber &number) {
 	quint64 n = number.toUint64();
 
 	decDisplay->setText(QString::number(n, 10));
@@ -2075,6 +2083,7 @@ void KCalculator::slotBitsetChanged(quint64 value) {
 
     calc_display->setAmount(KNumber(value));
     updateDisplay({});
+    core.setOnlyUpdateOperation(false);
 }
 
 //------------------------------------------------------------------------------
@@ -2118,7 +2127,6 @@ void KCalculator::updateDisplay(UpdateFlags flags) {
 
 	if(flags & UPDATE_FROM_CORE) {
 		calc_display->updateFromCore(core, (flags & UPDATE_STORE_RESULT) != 0);
-		core.setOnlyUpdateOperation(true);
 	} else {
 		calc_display->update();
 	}
@@ -2322,11 +2330,11 @@ bool KCalculator::eventFilter(QObject *o, QEvent *e) {
 				// Was it hex-button or normal digit??
 				if (num_but < 10) {
 					for (int i = 0; i < 10; ++i) {
-						(num_button_group_->buttons()[i])->setStyleSheet(sheet.arg(cn));
+                                                (num_button_group_->buttons().at(i))->setStyleSheet(sheet.arg(cn));
 					}
 				} else {
 					for (int i = 10; i < 16; ++i) {
-						(num_button_group_->buttons()[i])->setStyleSheet(sheet.arg(cn));
+                                                (num_button_group_->buttons().at(i))->setStyleSheet(sheet.arg(cn));
 					}
 				}
 				return true;
@@ -2354,6 +2362,15 @@ bool KCalculator::eventFilter(QObject *o, QEvent *e) {
 	}
 }
 
+//------------------------------------------------------------------------------
+// Name: slotPaste
+// Desc: paste a number from the clipboard
+//------------------------------------------------------------------------------
+void KCalculator::slotPaste() {
+    calc_display->slotPaste();
+    core.setOnlyUpdateOperation(false);
+}
+
 ////////////////////////////////////////////////////////////////
 // Include the meta-object code for classes in this file
 //
@@ -2388,7 +2405,7 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char *argv[]) {
                               "Copyright © 2000-2008, The KDE Team\n"
                               "Copyright © 2003-2005, Klaus Niederkr" "\xc3\xbc" "ger\n"
                               "Copyright © 1996-2000, Bernd Johannes Wuebben"),
-                         QStringLiteral(),
+                         QString(),
                          QStringLiteral("https://utils.kde.org/projects/kcalc"));
 
 	// Klaus Niederkrueger
